rowMSD: Mean and Standard Deviation estimates for each row in a...

View source: R/rowMSD.r

rowMSDR Documentation

Mean and Standard Deviation estimates for each row in a matrix

Description

Calculates the sample mean and standard deviation for each row in a matrix. The mean vector is calculated first. The elements of the matrix are then centered by the mean vector before the sample standard deviation is calculated.

Usage

rowMSD(x)

Arguments

x

numeric matrix

Value

A list consisting of:

rm

vector of row means

rsd

vector of row standard deviations

Author(s)

John Lawrence

Examples

x=matrix(rnorm(1000),nrow=10)
rowMSD(x)

SurvDisc documentation built on Aug. 2, 2026, 5:07 p.m.

Related to rowMSD in SurvDisc...