rowMSD: Mean and Standard Deviation estimates for each row in a matrix
Description
Calculates the sample mean and standard deviation for each row in a matrix. The mean vector is calculated first. The elements of the matrix are then centered by the mean vector before the sample standard deviation is calculated.